@@ -33,7 +33,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 
 
 ###############################################################################
@@ -85,6 +85,7 @@ sub new {
     $self->{_named_ranges}       = [];
     $self->{_custom_colors}      = [];
     $self->{_doc_properties}     = {};
+    $self->{_custom_properties}  = [];
     $self->{_createtime}         = [ gmtime() ];
     $self->{_num_vml_files}      = 0;
     $self->{_num_comment_files}  = 0;
@@ -855,6 +856,74 @@ sub set_properties {
 }
 
 
+###############################################################################
+#
+# set_custom_property()
+#
+# Set a user defined custom document property.
+#
+sub set_custom_property {
+
+    my $self  = shift;
+    my $name  = shift;
+    my $value = shift;
+    my $type  = shift;
+
+
+    # Valid types.
+    my %valid_type = (
+        'text'       => 1,
+        'date'       => 1,
+        'number'     => 1,
+        'number_int' => 1,
+        'bool'       => 1,
+    );
+
+    if ( !defined $name || !defined $value ) {
+        carp "The name and value parameters must be defined "
+          . "in set_custom_property()";
+
+        return -1;
+    }
+
+    # Determine the type for strings and numbers if it hasn't been specified.
+    if ( !$type ) {
+        if ( $value =~ /^\d+$/ ) {
+            $type = 'number_int';
+        }
+        elsif ( $value =~
+            /^([+-]?)(?=[0-9]|\.[0-9])[0-9]*(\.[0-9]*)?([Ee]([+-]?[0-9]+))?$/ )
+        {
+            $type = 'number';
+        }
+        else {
+            $type = 'text';
+        }
+    }
+
+    # Check for valid validation types.
+    if ( !exists $valid_type{$type} ) {
+        carp "Unknown custom type '$type' in set_custom_property()";
+        return -1;
+    }
+
+    #  Check for strings longer than Excel's limit of 255 chars.
+    if ( $type eq 'text' and length $value > 255 ) {
+        carp "Length of text custom value '$value' exceeds "
+          . "Excel's limit of 255 in set_custom_property()";
+        return -1;
+    }
+    if ( length $value > 255 ) {
+        carp "Length of custom name '$name' exceeds "
+          . "Excel's limit of 255 in set_custom_property()";
+        return -1;
+    }
+
+    push @{ $self->{_custom_properties} }, [ $name, $value, $type ];
+}
+
+
+
 ###############################################################################
 #
 # add_vba_project()
